export const slide = {
    slideEnter(el, done){
        this.$$(el).slideDown({
            duration: 300,
            done
        })
    },
    slideLeave(el, done){
        this.$$(el).slideUp({
            duration: 300,
            done
        })
    }
};
export function cSlide(duration:number=300){
    return {
        slideEnter(el, done){
            this.$$(el).slideDown({
                duration,
                done
            })
        },
        slideLeave(el, done){
            this.$$(el).slideUp({
                duration,
                done
            })
        }

    }
}
export const fade = {
    fadeEnter(el, done){
        this.$$(el).fadeIn({
            duration: 300,
            done
        })
    },
    fadeLeave(el, done){
        this.$$(el).fadeOut({
            duration: 300,
            done
        })
    }
}